package de.juplo.jpa.converters;

import java.sql.Timestamp;
import java.time.OffsetDateTime;
import javax.persistence.AttributeConverter;
import javax.persistence.Converter;


/**
 * Converts a {@link OffsetDateTime} to a {@link Timestamp}.
 * @author Kai Moritz
 */
@Converter(autoApply = true)
public class OffsetDateTimeConverter implements AttributeConverter<OffsetDateTime, Timestamp>
{
  @Override
  public Timestamp convertToDatabaseColumn(OffsetDateTime odt)
  {
    if (odt == null)
      return null;
    return Timestamp.valueOf(odt.withOffsetSameInstant(TimeConversions.getZoneOffset()).toLocalDateTime());
  }

  @Override
  public OffsetDateTime convertToEntityAttribute(Timestamp ts)
  {
    if (ts == null)
      return null;
    return OffsetDateTime.of(ts.toLocalDateTime(), TimeConversions.getZoneOffset());
  }
}
