package de.juplo.jpa.converters;

import java.sql.Time;
import java.time.OffsetTime;
import java.time.ZoneOffset;
import javax.persistence.AttributeConverter;
import javax.persistence.Converter;


/**
 * Converts an {@link OffsetTime} to a {@link Time}.
 * @author Kai Moritz
 */
@Converter(autoApply = true)
public class OffsetTimeConverter implements AttributeConverter<OffsetTime, Time>
{
  @Override
  public Time convertToDatabaseColumn(OffsetTime ot)
  {
    if (ot == null)
      return null;
    ZoneOffset offset = ot.getOffset();
    return Time.valueOf(ot.withOffsetSameInstant(ZoneOffset.UTC).toLocalTime());
  }

  @Override
  public OffsetTime convertToEntityAttribute(Time time)
  {
    if (time == null)
      return null;
    return OffsetTime.of(time.toLocalTime(), ZoneOffset.UTC);
  }
}
