package de.juplo.jpa.converters;

import java.time.Duration;
import java.time.temporal.ChronoUnit;
import java.time.temporal.TemporalAmount;
import javax.persistence.AttributeConverter;
import javax.persistence.Converter;


/**
 * Converts a {@link TemporalAmount} into a {@link Long} representing hours.
 * @author Kai Moritz
 */
@Converter
public class TemporalAmountToHoursConverter implements AttributeConverter<TemporalAmount, Long>
{
  @Override
  public Long convertToDatabaseColumn(TemporalAmount amount)
  {
    if (amount == null)
      return null;
    return amount.get(ChronoUnit.HOURS);
  }

  @Override
  public TemporalAmount convertToEntityAttribute(Long hours)
  {
    if (hours == null)
      return null;
    return Duration.ofHours(hours);
  }
}
