package de.juplo.jpa.converters;

import java.time.Duration;
import java.time.temporal.ChronoUnit;
import java.time.temporal.TemporalAmount;
import javax.persistence.AttributeConverter;
import javax.persistence.Converter;


/**
 * Converts a {@link TemporalAmount} into a {@link Long} representing
 * microseconds.
 * @author Kai Moritz
 */
@Converter
public class TemporalAmountToMicrosConverter implements AttributeConverter<TemporalAmount, Long>
{
  @Override
  public Long convertToDatabaseColumn(TemporalAmount amount)
  {
    if (amount == null)
      return null;
    return amount.get(ChronoUnit.MICROS);
  }

  @Override
  public TemporalAmount convertToEntityAttribute(Long micros)
  {
    if (micros == null)
      return null;
    return Duration.of(micros, ChronoUnit.MICROS);
  }
}
