package de.juplo.jpa.converters;

import java.time.Duration;
import java.time.temporal.ChronoUnit;
import java.time.temporal.TemporalAmount;
import javax.persistence.AttributeConverter;
import javax.persistence.Converter;


/**
 * Converts a {@link TemporalAmount} into a {@link Long} representing minutes.
 * @author Kai Moritz
 */
@Converter
public class TemporalAmountToMinutesConverter implements AttributeConverter<TemporalAmount, Long>
{
  @Override
  public Long convertToDatabaseColumn(TemporalAmount amount)
  {
    if (amount == null)
      return null;
    return amount.get(ChronoUnit.MINUTES);
  }

  @Override
  public TemporalAmount convertToEntityAttribute(Long minutes)
  {
    if (minutes == null)
      return null;
    return Duration.ofMinutes(minutes);
  }
}
