package de.juplo.jpa.converters;

import java.time.Duration;
import java.time.temporal.ChronoUnit;
import java.time.temporal.TemporalAmount;
import javax.persistence.AttributeConverter;
import javax.persistence.Converter;


/**
 * Converts a {@link TemporalAmount} into a {@link Long} representing
 * nanoseconds.
 * @author Kai Moritz
 */
@Converter
public class TemporalAmountToNanosConverter implements AttributeConverter<TemporalAmount, Long>
{
  @Override
  public Long convertToDatabaseColumn(TemporalAmount amount)
  {
    if (amount == null)
      return null;
    return amount.get(ChronoUnit.NANOS);
  }

  @Override
  public TemporalAmount convertToEntityAttribute(Long nanos)
  {
    if (nanos == null)
      return null;
    return Duration.ofNanos(nanos);
  }
}
