package de.juplo.jpa.converters;

import java.sql.Timestamp;
import java.time.ZonedDateTime;
import javax.persistence.AttributeConverter;
import javax.persistence.Converter;


/**
 * Converts a {@link ZonedDateTime} to a {@link Timestamp}.
 * @author Kai Moritz
 */
@Converter(autoApply = true)
public class ZonedDateTimeConverter implements AttributeConverter<ZonedDateTime, Timestamp>
{
  @Override
  public Timestamp convertToDatabaseColumn(ZonedDateTime zdt)
  {
    if (zdt == null)
      return null;
    return Timestamp.from(zdt.withZoneSameInstant(TimeConversions.getZoneId()).toInstant());
  }

  @Override
  public ZonedDateTime convertToEntityAttribute(Timestamp ts)
  {
    if (ts == null)
      return null;
    return ZonedDateTime.ofInstant(ts.toInstant(), TimeConversions.getZoneId());
  }
}
